==> openshift-model-5.8.0-sources.jar: io/fabric8/openshift/api/model/InfrastructureStatusFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface InfrastructureStatusFluent<A extends io.fabric8.openshift.api.model.InfrastructureStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getApiServerInternalURI();
  public A withApiServerInternalURI(java.lang.String apiServerInternalURI);
  public java.lang.Boolean hasApiServerInternalURI();
  
  /**
   * Method is deprecated. use withApiServerInternalURI instead.
   */
  @java.lang.Deprecated
  public A withNewApiServerInternalURI(java.lang.String arg0);
  public java.lang.String getApiServerURL();
  public A withApiServerURL(java.lang.String apiServerURL);
  public java.lang.Boolean hasApiServerURL();
  
  /**
   * Method is deprecated. use withApiServerURL instead.
   */
  @java.lang.Deprecated
  public A withNewApiServerURL(java.lang.String arg0);
  public java.lang.String getControlPlaneTopology();
  public A withControlPlaneTopology(java.lang.String controlPlaneTopology);
  public java.lang.Boolean hasControlPlaneTopology();
  
  /**
   * Method is deprecated. use withControlPlaneTopology instead.
   */
  @java.lang.Deprecated
  public A withNewControlPlaneTopology(java.lang.String arg0);
  public java.lang.String getEtcdDiscoveryDomain();
  public A withEtcdDiscoveryDomain(java.lang.String etcdDiscoveryDomain);
  public java.lang.Boolean hasEtcdDiscoveryDomain();
  
  /**
   * Method is deprecated. use withEtcdDiscoveryDomain instead.
   */
  @java.lang.Deprecated
  public A withNewEtcdDiscoveryDomain(java.lang.String arg0);
  public java.lang.String getInfrastructureName();
  public A withInfrastructureName(java.lang.String infrastructureName);
  public java.lang.Boolean hasInfrastructureName();
  
  /**
   * Method is deprecated. use withInfrastructureName instead.
   */
  @java.lang.Deprecated
  public A withNewInfrastructureName(java.lang.String arg0);
  public java.lang.String getInfrastructureTopology();
  public A withInfrastructureTopology(java.lang.String infrastructureTopology);
  public java.lang.Boolean hasInfrastructureTopology();
  
  /**
   * Method is deprecated. use withInfrastructureTopology instead.
   */
  @java.lang.Deprecated
  public A withNewInfrastructureTopology(java.lang.String arg0);
  public java.lang.String getPlatform();
  public A withPlatform(java.lang.String platform);
  public java.lang.Boolean hasPlatform();
  
  /**
   * Method is deprecated. use withPlatform instead.
   */
  @java.lang.Deprecated
  public A withNewPlatform(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildPlatformStatus instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.PlatformStatus getPlatformStatus();
  public io.fabric8.openshift.api.model.PlatformStatus buildPlatformStatus();
  public A withPlatformStatus(io.fabric8.openshift.api.model.PlatformStatus platformStatus);
  public java.lang.Boolean hasPlatformStatus();
  public io.fabric8.openshift.api.model.InfrastructureStatusFluent.PlatformStatusNested<A> withNewPlatformStatus();
  public io.fabric8.openshift.api.model.InfrastructureStatusFluent.PlatformStatusNested<A> withNewPlatformStatusLike(io.fabric8.openshift.api.model.PlatformStatus item);
  public io.fabric8.openshift.api.model.InfrastructureStatusFluent.PlatformStatusNested<A> editPlatformStatus();
  public io.fabric8.openshift.api.model.InfrastructureStatusFluent.PlatformStatusNested<A> editOrNewPlatformStatus();
  public io.fabric8.openshift.api.model.InfrastructureStatusFluent.PlatformStatusNested<A> editOrNewPlatformStatusLike(io.fabric8.openshift.api.model.PlatformStatus item);
  public interface PlatformStatusNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.PlatformStatusFluent<io.fabric8.openshift.api.model.InfrastructureStatusFluent.PlatformStatusNested<N>>{
    public N and();
    public N endPlatformStatus();
    
  }
  
}

==> openshift-model-5.10.2-sources.jar: io/fabric8/openshift/api/model/InfrastructureStatusFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface InfrastructureStatusFluent<A extends io.fabric8.openshift.api.model.InfrastructureStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getApiServerInternalURI();
  public A withApiServerInternalURI(java.lang.String apiServerInternalURI);
  public java.lang.Boolean hasApiServerInternalURI();
  
  /**
   * Method is deprecated. use withApiServerInternalURI instead.
   */
  @java.lang.Deprecated
  public A withNewApiServerInternalURI(java.lang.String arg0);
  public java.lang.String getApiServerURL();
  public A withApiServerURL(java.lang.String apiServerURL);
  public java.lang.Boolean hasApiServerURL();
  
  /**
   * Method is deprecated. use withApiServerURL instead.
   */
  @java.lang.Deprecated
  public A withNewApiServerURL(java.lang.String arg0);
  public java.lang.String getControlPlaneTopology();
  public A withControlPlaneTopology(java.lang.String controlPlaneTopology);
  public java.lang.Boolean hasControlPlaneTopology();
  
  /**
   * Method is deprecated. use withControlPlaneTopology instead.
   */
  @java.lang.Deprecated
  public A withNewControlPlaneTopology(java.lang.String arg0);
  public java.lang.String getEtcdDiscoveryDomain();
  public A withEtcdDiscoveryDomain(java.lang.String etcdDiscoveryDomain);
  public java.lang.Boolean hasEtcdDiscoveryDomain();
  
  /**
   * Method is deprecated. use withEtcdDiscoveryDomain instead.
   */
  @java.lang.Deprecated
  public A withNewEtcdDiscoveryDomain(java.lang.String arg0);
  public java.lang.String getInfrastructureName();
  public A withInfrastructureName(java.lang.String infrastructureName);
  public java.lang.Boolean hasInfrastructureName();
  
  /**
   * Method is deprecated. use withInfrastructureName instead.
   */
  @java.lang.Deprecated
  public A withNewInfrastructureName(java.lang.String arg0);
  public java.lang.String getInfrastructureTopology();
  public A withInfrastructureTopology(java.lang.String infrastructureTopology);
  public java.lang.Boolean hasInfrastructureTopology();
  
  /**
   * Method is deprecated. use withInfrastructureTopology instead.
   */
  @java.lang.Deprecated
  public A withNewInfrastructureTopology(java.lang.String arg0);
  public java.lang.String getPlatform();
  public A withPlatform(java.lang.String platform);
  public java.lang.Boolean hasPlatform();
  
  /**
   * Method is deprecated. use withPlatform instead.
   */
  @java.lang.Deprecated
  public A withNewPlatform(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildPlatformStatus instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.PlatformStatus getPlatformStatus();
  public io.fabric8.openshift.api.model.PlatformStatus buildPlatformStatus();
  public A withPlatformStatus(io.fabric8.openshift.api.model.PlatformStatus platformStatus);
  public java.lang.Boolean hasPlatformStatus();
  public io.fabric8.openshift.api.model.InfrastructureStatusFluent.PlatformStatusNested<A> withNewPlatformStatus();
  public io.fabric8.openshift.api.model.InfrastructureStatusFluent.PlatformStatusNested<A> withNewPlatformStatusLike(io.fabric8.openshift.api.model.PlatformStatus item);
  public io.fabric8.openshift.api.model.InfrastructureStatusFluent.PlatformStatusNested<A> editPlatformStatus();
  public io.fabric8.openshift.api.model.InfrastructureStatusFluent.PlatformStatusNested<A> editOrNewPlatformStatus();
  public io.fabric8.openshift.api.model.InfrastructureStatusFluent.PlatformStatusNested<A> editOrNewPlatformStatusLike(io.fabric8.openshift.api.model.PlatformStatus item);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface PlatformStatusNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.PlatformStatusFluent<io.fabric8.openshift.api.model.InfrastructureStatusFluent.PlatformStatusNested<N>>{
    public N and();
    public N endPlatformStatus();
    
  }
  
}
